@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,33 +18,42 @@ package org.drools.workbench.screens.testscenario.client;
 
 import java.lang.annotation.Annotation;
 import java.util.Collections;
+import java.util.Optional;
+import java.util.function.Supplier;
+
 import javax.enterprise.event.Event;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.drools.workbench.models.datamodel.imports.HasImports;
+import org.drools.workbench.models.testscenarios.shared.ExecutionTrace;
 import org.drools.workbench.models.testscenarios.shared.Scenario;
+import org.drools.workbench.screens.testscenario.client.page.audit.AuditPage;
+import org.drools.workbench.screens.testscenario.client.page.settings.SettingsPage;
 import org.drools.workbench.screens.testscenario.client.resources.i18n.TestScenarioConstants;
 import org.drools.workbench.screens.testscenario.client.type.TestScenarioResourceType;
 import org.drools.workbench.screens.testscenario.model.TestScenarioModelContent;
 import org.drools.workbench.screens.testscenario.model.TestScenarioResult;
 import org.drools.workbench.screens.testscenario.service.ScenarioTestEditorService;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
-import org.guvnor.common.services.project.context.ProjectContext;
-import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.common.services.shared.test.TestService;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.bus.client.api.messaging.Message;
+import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.soup.project.datamodel.imports.HasImports;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracleFactory;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilderImpl;
 import org.kie.workbench.common.widgets.configresource.client.widget.bound.ImportsWidgetPresenter;
 import org.kie.workbench.common.widgets.metadata.client.KieEditorWrapperView;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
@@ -58,14 +67,30 @@ import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
 import org.uberfire.ext.editor.commons.client.resources.i18n.CommonConstants;
-import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
+import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.workbench.category.Others;
 import org.uberfire.workbench.events.NotificationEvent;
+import org.uberfire.workbench.model.menu.MenuItem;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.mockito.Matchers.notNull;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyBoolean;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.doThrow;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.inOrder;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.reset;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class ScenarioEditorPresenterTest {
@@ -114,8 +139,21 @@ public class ScenarioEditorPresenterTest {
     private ProjectController projectController;
 
     @Mock
-    private ProjectContext workbenchContext;
+    private WorkspaceProjectContext workbenchContext;
 
+    @Mock
+    private SettingsPage settingsPage;
+
+    @Mock
+    private AuditPage auditPage;
+
+    @Mock
+    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+
+    @Mock
+    protected MenuItem alertsButtonMenuItem;
+
+    private CallerMock<ScenarioTestEditorService> fakeService;
     private ScenarioEditorPresenter editor;
     private Scenario scenario;
     private Overview overview;
@@ -126,13 +164,16 @@ public class ScenarioEditorPresenterTest {
 
         final AsyncPackageDataModelOracleFactory modelOracleFactory = mock(AsyncPackageDataModelOracleFactory.class);
 
+        fakeService = new CallerMock<>(service);
         editor = spy(new ScenarioEditorPresenter(view,
                                                  user,
                                                  importsWidget,
-                                                 new CallerMock<>(service),
+                                                 fakeService,
                                                  new CallerMock<>(testService),
-                                                 new TestScenarioResourceType(),
-                                                 modelOracleFactory) {
+                                                 new TestScenarioResourceType(new Others()),
+                                                 modelOracleFactory,
+                                                 settingsPage,
+                                                 auditPage) {
             {
                 kieView = ScenarioEditorPresenterTest.this.kieView;
                 versionRecordManager = ScenarioEditorPresenterTest.this.versionRecordManager;
@@ -142,15 +183,26 @@ public class ScenarioEditorPresenterTest {
                 projectController = ScenarioEditorPresenterTest.this.projectController;
                 workbenchContext = ScenarioEditorPresenterTest.this.workbenchContext;
                 versionRecordManager = ScenarioEditorPresenterTest.this.versionRecordManager;
+                alertsButtonMenuItemBuilder = ScenarioEditorPresenterTest.this.alertsButtonMenuItemBuilder;
+            }
+
+            @Override
+            protected Command getSaveAndRename() {
+                return mock(Command.class);
             }
         });
 
+        doNothing().when(editor).addDownloadMenuItem(any());
+
         scenarioRunResult = new Scenario();
         scenario = new Scenario();
         overview = new Overview();
 
         when(user.getIdentifier()).thenReturn("userName");
 
+        when(workbenchContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
+        when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.empty());
+
         final TestScenarioModelContent testScenarioModelContent = new TestScenarioModelContent(scenario,
                                                                                                overview,
                                                                                                "org.test",
@@ -169,6 +221,8 @@ public class ScenarioEditorPresenterTest {
                                                                 any(HasImports.class),
                                                                 any(PackageDataModelOracleBaselinePayload.class))
         ).thenReturn(dmo);
+
+        when(alertsButtonMenuItemBuilder.build()).thenReturn(alertsButtonMenuItem);
     }
 
     @Test
@@ -193,8 +247,6 @@ public class ScenarioEditorPresenterTest {
         editor.onRunScenario();
 
         // Make sure imports are updated
-        verify(view).initKSessionSelector(path,
-                                          scenarioRunResult);
         verify(importsWidget).setContent(any(AsyncPackageDataModelOracle.class),
                                          eq(scenarioRunResult.getImports()),
                                          anyBoolean());
@@ -226,6 +278,18 @@ public class ScenarioEditorPresenterTest {
                                     eq(scenario));
     }
 
+    @Test
+    public void testKiePageRefreshAfterContentLoaded() throws Exception {
+        final ObservablePath path = mock(ObservablePath.class);
+        when(versionRecordManager.getCurrentPath()).thenReturn(path);
+
+        editor.loadContent();
+
+        verify(kieView).addPage(settingsPage);
+        verify(kieView).addPage(auditPage);
+        verify(settingsPage).refresh(view, path, scenario);
+    }
+
     @Test
     public void testRunScenario() throws Exception {
         final ObservablePath path = mock(ObservablePath.class);
@@ -236,9 +300,6 @@ public class ScenarioEditorPresenterTest {
         editor.onStartup(path,
                          placeRequest);
 
-        verify(view).initKSessionSelector(eq(path),
-                                          any(Scenario.class));
-
         reset(view);
 
         editor.onRunScenario();
@@ -246,10 +307,12 @@ public class ScenarioEditorPresenterTest {
         InOrder inOrder = inOrder(view);
         inOrder.verify(view).showBusyIndicator(TestScenarioConstants.INSTANCE.BuildingAndRunningScenario());
         inOrder.verify(view).showResults();
-        inOrder.verify(view).showAuditView(anySet());
         inOrder.verify(view).hideBusyIndicator();
-        inOrder.verify(view).initKSessionSelector(eq(path),
-                                                  any(Scenario.class));
+
+        verify(settingsPage).refresh(view, path, scenario);
+
+        verify(auditPage).showFiredRulesAuditLog(Collections.emptySet());
+        verify(auditPage).showFiredRules(notNull(ExecutionTrace.class));
     }
 
     @Test
@@ -304,22 +367,24 @@ public class ScenarioEditorPresenterTest {
 
     @Test
     public void testMakeMenuBar() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(true).when(projectController).canUpdateProject(any());
 
         editor.makeMenuBar();
 
         verify(fileMenuBuilder).addSave(any(Command.class));
         verify(fileMenuBuilder).addCopy(any(Path.class),
-                                        any(DefaultFileNameValidator.class));
-        verify(fileMenuBuilder).addRename(any(Path.class),
-                                          any(DefaultFileNameValidator.class));
-        verify(fileMenuBuilder).addDelete(any(Path.class));
+                                        any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addRename(any(Command.class));
+        verify(fileMenuBuilder).addDelete(any(Path.class),
+                                          any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
+        verify(editor).addDownloadMenuItem(fileMenuBuilder);
     }
 
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(false).when(projectController).canUpdateProject(any());
 
         editor.makeMenuBar();
@@ -328,12 +393,34 @@ public class ScenarioEditorPresenterTest {
                never()).addSave(any(Command.class));
         verify(fileMenuBuilder,
                never()).addCopy(any(Path.class),
-                                any(DefaultFileNameValidator.class));
+                                any(AssetUpdateValidator.class));
         verify(fileMenuBuilder,
                never()).addRename(any(Path.class),
-                                  any(DefaultFileNameValidator.class));
+                                  any(AssetUpdateValidator.class));
         verify(fileMenuBuilder,
-               never()).addDelete(any(Path.class));
+               never()).addDelete(any(Path.class),
+                                  any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
+    }
+
+    @Test
+    public void testGetContentSupplier() throws Exception {
+
+        final Scenario content = mock(Scenario.class);
+
+        doReturn(content).when(editor).getScenario();
+
+        final Supplier<Scenario> contentSupplier = editor.getContentSupplier();
+
+        assertEquals(content, contentSupplier.get());
+    }
+
+    @Test
+    public void testGetSaveAndRenameServiceCaller() throws Exception {
+
+        final Caller<? extends SupportsSaveAndRename<Scenario, Metadata>> serviceCaller = editor.getSaveAndRenameServiceCaller();
+
+        assertEquals(fakeService, serviceCaller);
     }
 
     private Event<NotificationEvent> makeNotificationEvent() {
